@@ -73,12 +73,23 @@ public class Component3DManager {
 
   private Component3DManager() {
     if (!GraphicsEnvironment.isHeadless()) {
-      GraphicsConfigTemplate3D template = createGraphicsConfigurationTemplate3D();
-      GraphicsDevice defaultScreenDevice = GraphicsEnvironment.getLocalGraphicsEnvironment().getDefaultScreenDevice();
-      this.defaultScreenConfiguration = defaultScreenDevice.getBestConfiguration(template);
-      if (this.defaultScreenConfiguration == null) {
-        template = new GraphicsConfigTemplate3D();
-        this.defaultScreenConfiguration = defaultScreenDevice.getBestConfiguration(template);
+      // Request depth size equal to 24 if supported
+      int preferredDepthSize = 24;
+      try {
+        preferredDepthSize = Integer.valueOf(System.getProperty("com.eteks.sweethome3d.j3d.depthSize", "24"));
+      } catch (NumberFormatException ex) {
+        // Keep 24
+      }
+      GraphicsConfigTemplate3D template = createGraphicsConfigurationTemplate3D(preferredDepthSize);
+      this.defaultScreenConfiguration = createScreenConfiguration(template);
+      if (OperatingSystem.isWindows()) {
+        if (!isOffScreenImageSupported()) {
+          // Try again with default depth size
+          template = createGraphicsConfigurationTemplate3D(new GraphicsConfigTemplate3D().getDepthSize());
+          this.defaultScreenConfiguration = createScreenConfiguration(template);
+          // Reset offscreen support flag
+          this.offScreenImageSupported = null;
+        }
       }
       this.depthSize = template.getDepthSize();
     } else {
@@ -89,25 +100,19 @@ public class Component3DManager {
   /**
    * Returns the template to configure the graphics of canvas 3D.
    */
-  private GraphicsConfigTemplate3D createGraphicsConfigurationTemplate3D() {
+  private GraphicsConfigTemplate3D createGraphicsConfigurationTemplate3D(int preferredDepthSize) {
     if (System.getProperty("j3d.implicitAntialiasing") == null) {
       System.setProperty("j3d.implicitAntialiasing", "true");
     }
-    // Retrieve graphics configuration once
-    GraphicsConfigTemplate3D template = new GraphicsConfigTemplate3D();
 
-    // Request depth size equal to 24 if supported
-    int preferredDepthSize = 24;
-    try {
-      preferredDepthSize = Integer.valueOf(System.getProperty("com.eteks.sweethome3d.j3d.depthSize", "24"));
-    } catch (NumberFormatException ex) {
-      // Keep 24
-    }
+    GraphicsConfigTemplate3D template = new GraphicsConfigTemplate3D();
     int defaultDepthSize = template.getDepthSize();
-    template.setDepthSize(preferredDepthSize);
-    if (!template.isGraphicsConfigSupported(
-        GraphicsEnvironment.getLocalGraphicsEnvironment().getDefaultScreenDevice().getDefaultConfiguration())) {
-      template.setDepthSize(defaultDepthSize);
+    if (defaultDepthSize != preferredDepthSize) {
+      template.setDepthSize(preferredDepthSize);
+      if (!template.isGraphicsConfigSupported(
+          GraphicsEnvironment.getLocalGraphicsEnvironment().getDefaultScreenDevice().getDefaultConfiguration())) {
+        template.setDepthSize(defaultDepthSize);
+      }
     }
 
     // Try to get antialiasing
@@ -127,6 +132,19 @@ public class Component3DManager {
     return template;
   }
 
+  /**
+   * Returns a screen configuration from the preferred template.
+   */
+  private GraphicsConfiguration createScreenConfiguration(GraphicsConfigTemplate template) {
+    GraphicsDevice defaultScreenDevice = GraphicsEnvironment.getLocalGraphicsEnvironment().getDefaultScreenDevice();
+    GraphicsConfiguration screenConfiguration = defaultScreenDevice.getBestConfiguration(template);
+    if (screenConfiguration == null) {
+      template = new GraphicsConfigTemplate3D();
+      screenConfiguration = defaultScreenDevice.getBestConfiguration(template);
+    }
+    return screenConfiguration;
+  }
+
   /**
    * Returns the depth bits size of the Z-buffer.
    */
@@ -217,7 +235,7 @@ public class Component3DManager {
                || deviceConfiguration.getDevice() == this.defaultScreenConfiguration.getDevice()) {
       configuration = this.defaultScreenConfiguration;
     } else {
-      GraphicsConfigTemplate3D template = createGraphicsConfigurationTemplate3D();
+      GraphicsConfigTemplate3D template = createGraphicsConfigurationTemplate3D(this.depthSize);
       configuration = deviceConfiguration.getDevice().getBestConfiguration(template);
       if (configuration == null) {
         configuration = deviceConfiguration.getDevice().getBestConfiguration(new GraphicsConfigTemplate3D());
@@ -369,7 +387,7 @@ public class Component3DManager {
       offScreenCanvas.waitForOffScreenRendering();
 
       // If latch count becomes equal to 0 during the past instructions or in the coming 10 milliseconds,
-      // this means that a rendering error happened
+      // this means that a rendering error happened (for example, in case changing default depth size isn't supported)
       if (latch.await(10, TimeUnit.MILLISECONDS)) {
         throw new IllegalRenderingStateException("Off screen rendering unavailable");
       }
