@@ -31,6 +31,7 @@ import java.util.List;
 import javax.media.j3d.Appearance;
 import javax.media.j3d.BranchGroup;
 import javax.media.j3d.Geometry;
+import javax.media.j3d.Group;
 import javax.media.j3d.Node;
 import javax.media.j3d.RenderingAttributes;
 import javax.media.j3d.Shape3D;
@@ -40,6 +41,7 @@ import javax.vecmath.Point3f;
 import javax.vecmath.TexCoord2f;
 
 import com.eteks.sweethome3d.model.Home;
+import com.eteks.sweethome3d.model.HomeEnvironment;
 import com.eteks.sweethome3d.model.HomeFurnitureGroup;
 import com.eteks.sweethome3d.model.HomePieceOfFurniture;
 import com.eteks.sweethome3d.model.HomeTexture;
@@ -55,7 +57,7 @@ import com.sun.j3d.utils.geometry.NormalGenerator;
 public class Room3D extends Object3DBranch {
   private static final int FLOOR_PART  = 0;
   private static final int CEILING_PART = 1;
-  
+
   private final Home home;
 
   /**
@@ -71,6 +73,16 @@ public class Room3D extends Object3DBranch {
   public Room3D(Room room, Home home,
                 boolean ignoreCeilingPart,
                 boolean waitTextureLoadingEnd) {
+    this(room, home, ignoreCeilingPart, true, waitTextureLoadingEnd);
+  }
+
+  /**
+   * Creates the 3D room matching the given home <code>room</code>.
+   */
+  public Room3D(Room room, Home home,
+                boolean ignoreCeilingPart,
+                boolean ignoreDrawingMode,
+                boolean waitTextureLoadingEnd) {
     setUserData(room);
     this.home = home;
 
@@ -78,24 +90,34 @@ public class Room3D extends Object3DBranch {
     setCapability(BranchGroup.ALLOW_DETACH);
     // Allow to read branch shape children
     setCapability(BranchGroup.ALLOW_CHILDREN_READ);
-    
+
     // Add room floor and cellar empty shapes to branch
-    addChild(createRoomPartShape());
-    addChild(createRoomPartShape());
+    for (int i = 0; i < 2; i++) {
+      Group roomPartGroup = new Group();
+      roomPartGroup.setCapability(Group.ALLOW_CHILDREN_READ);
+      roomPartGroup.addChild(createRoomPartShape(false));
+      if (!ignoreDrawingMode) {
+        roomPartGroup.addChild(createRoomPartShape(true));
+      }
+      addChild(roomPartGroup);
+    }
     // Set room shape geometry and appearance
     updateRoomGeometry();
     updateRoomAppearance(waitTextureLoadingEnd);
-    
+
     if (ignoreCeilingPart) {
       removeChild(CEILING_PART);
+    } else {
+      // Avoid making ceiling pickable because they can't be viewed from top
+      getChild(CEILING_PART).setPickable(false);
     }
   }
 
   /**
-   * Returns a new room part shape with no geometry  
+   * Returns a new room part shape with no geometry
    * and a default appearance with a white material.
    */
-  private Node createRoomPartShape() {
+  private Node createRoomPartShape(boolean outline) {
     Shape3D roomShape = new Shape3D();
     // Allow room shape to change its geometry
     roomShape.setCapability(Shape3D.ALLOW_GEOMETRY_WRITE);
@@ -113,12 +135,19 @@ public class Room3D extends Object3DBranch {
     RenderingAttributes renderingAttributes = new RenderingAttributes();
     renderingAttributes.setCapability(RenderingAttributes.ALLOW_VISIBLE_WRITE);
     roomAppearance.setRenderingAttributes(renderingAttributes);
-    roomAppearance.setCapability(Appearance.ALLOW_MATERIAL_WRITE);
-    roomAppearance.setMaterial(DEFAULT_MATERIAL);      
-    roomAppearance.setCapability(Appearance.ALLOW_TEXTURE_WRITE);
-    roomAppearance.setCapability(Appearance.ALLOW_TEXTURE_READ);
-    roomAppearance.setCapability(Appearance.ALLOW_TEXTURE_ATTRIBUTES_WRITE);
-    
+
+    if (outline) {
+      roomAppearance.setColoringAttributes(Object3DBranch.OUTLINE_COLORING_ATTRIBUTES);
+      roomAppearance.setPolygonAttributes(Object3DBranch.OUTLINE_POLYGON_ATTRIBUTES);
+      roomAppearance.setLineAttributes(Object3DBranch.OUTLINE_LINE_ATTRIBUTES);
+    } else {
+      roomAppearance.setCapability(Appearance.ALLOW_MATERIAL_WRITE);
+      roomAppearance.setMaterial(DEFAULT_MATERIAL);
+      roomAppearance.setCapability(Appearance.ALLOW_TEXTURE_WRITE);
+      roomAppearance.setCapability(Appearance.ALLOW_TEXTURE_READ);
+      roomAppearance.setCapability(Appearance.ALLOW_TEXTURE_ATTRIBUTES_WRITE);
+    }
+
     return roomShape;
   }
 
@@ -127,29 +156,39 @@ public class Room3D extends Object3DBranch {
     updateRoomGeometry();
     updateRoomAppearance(false);
   }
-  
+
   /**
-   * Sets the 3D geometry of this room shapes that matches its 2D geometry.  
+   * Sets the 3D geometry of this room shapes that matches its 2D geometry.
    */
   private void updateRoomGeometry() {
     updateRoomPartGeometry(FLOOR_PART, ((Room)getUserData()).getFloorTexture());
     updateRoomPartGeometry(CEILING_PART, ((Room)getUserData()).getCeilingTexture());
   }
-  
+
   private void updateRoomPartGeometry(int roomPart, HomeTexture texture) {
-    Shape3D roomShape = (Shape3D)getChild(roomPart);
-    int currentGeometriesCount = roomShape.numGeometries();
+    Group roomPartGroup = (Group)getChild(roomPart);
+    Shape3D roomFilledShape = (Shape3D)roomPartGroup.getChild(0);
+    Shape3D roomOutlineShape = roomPartGroup.numChildren() > 1
+        ? (Shape3D)roomPartGroup.getChild(1)
+        : null;
+    int currentGeometriesCount = roomFilledShape.numGeometries();
     Room room = (Room)getUserData();
     if (room.getLevel() == null || room.getLevel().isViewableAndVisible()) {
       for (Geometry roomGeometry : createRoomGeometries(roomPart, texture)) {
-        roomShape.addGeometry(roomGeometry);
+        roomFilledShape.addGeometry(roomGeometry);
+        if (roomOutlineShape != null) {
+          roomOutlineShape.addGeometry(roomGeometry);
+        }
       }
     }
     for (int i = currentGeometriesCount - 1; i >= 0; i--) {
-      roomShape.removeGeometry(i);
+      roomFilledShape.removeGeometry(i);
+      if (roomOutlineShape != null) {
+        roomOutlineShape.removeGeometry(i);
+      }
     }
   }
-  
+
   /**
    * Returns room geometry computed from its points.
    */
@@ -178,12 +217,12 @@ public class Room3D extends Object3DBranch {
       } else {
         firstLevelElevation = levels.get(0).getElevation();
       }
-      boolean floorBottomVisible = roomPart == FLOOR_PART 
-          && roomLevel != null 
+      boolean floorBottomVisible = roomPart == FLOOR_PART
+          && roomLevel != null
           && roomElevation != firstLevelElevation;
 
-      // Find rooms at the same elevation 
-      // and room ceilings at same elevation as the floor bottom  
+      // Find rooms at the same elevation
+      // and room ceilings at same elevation as the floor bottom
       final List<Room> roomsAtSameElevation = new ArrayList<Room>();
       List<Room> ceilingsAtSameFloorBottomElevation = new ArrayList<Room>();
       for (Room homeRoom : this.home.getRooms()) {
@@ -192,22 +231,22 @@ public class Room3D extends Object3DBranch {
           if (room == homeRoom // Store also the room itself to know its order among rooms at same elevation
               || roomLevel == homeRoomLevel
                   && (roomPart == FLOOR_PART && homeRoom.isFloorVisible()
-                      || roomPart == CEILING_PART && homeRoom.isCeilingVisible()) 
-              || roomLevel != null 
-                  && homeRoomLevel != null 
-                  && (roomPart == FLOOR_PART 
+                      || roomPart == CEILING_PART && homeRoom.isCeilingVisible())
+              || roomLevel != null
+                  && homeRoomLevel != null
+                  && (roomPart == FLOOR_PART
                           && homeRoom.isFloorVisible()
                           && Math.abs(roomElevation - homeRoomLevel.getElevation()) < 1E-4
-                      || roomPart == CEILING_PART 
+                      || roomPart == CEILING_PART
                           && homeRoom.isCeilingVisible()
                           && !lastLevel
                           && !isLastLevel(homeRoomLevel, levels)
-                          && Math.abs(roomElevation + roomLevel.getHeight() - (homeRoomLevel.getElevation() + homeRoomLevel.getHeight())) < 1E-4)) {         
+                          && Math.abs(roomElevation + roomLevel.getHeight() - (homeRoomLevel.getElevation() + homeRoomLevel.getHeight())) < 1E-4)) {
             roomsAtSameElevation.add(homeRoom);
-          } else if (floorBottomVisible 
-                      && homeRoomLevel != null 
-                      && homeRoom.isCeilingVisible() 
-                      && !isLastLevel(homeRoomLevel, levels) 
+          } else if (floorBottomVisible
+                      && homeRoomLevel != null
+                      && homeRoom.isCeilingVisible()
+                      && !isLastLevel(homeRoomLevel, levels)
                       && Math.abs(floorBottomElevation - (homeRoomLevel.getElevation() + homeRoomLevel.getHeight())) < 1E-4) {
             ceilingsAtSameFloorBottomElevation.add(homeRoom);
           }
@@ -226,14 +265,14 @@ public class Room3D extends Object3DBranch {
             }
           });
       }
-      
+
       List<HomePieceOfFurniture> visibleStaircases;
       if (roomLevel == null
           || roomPart == CEILING_PART
               && lastLevel) {
         visibleStaircases = Collections.emptyList();
       } else {
-        visibleStaircases = getVisibleStaircases(this.home.getFurniture(), roomPart, roomLevel, 
+        visibleStaircases = getVisibleStaircases(this.home.getFurniture(), roomPart, roomLevel,
             roomLevel.getElevation() == firstLevelElevation);
       }
 
@@ -246,17 +285,17 @@ public class Room3D extends Object3DBranch {
           sameElevation = getRoomHeightAt(points [i][0], points [i][1]) == firstPointElevation;
         }
       }
-      
+
       // Retrieve room points
       List<float [][]> roomPoints;
       List<float [][]> roomHoles;
       List<float [][]> roomPointsWithoutHoles;
       Area roomVisibleArea;
-      // If room isn't singular retrieve all the points of its different polygons 
-      if (!room.isSingular() 
+      // If room isn't singular retrieve all the points of its different polygons
+      if (!room.isSingular()
           || sameElevation
               && (roomsAtSameElevation.get(roomsAtSameElevation.size() - 1) != room
-                  || visibleStaircases.size() > 0)) {        
+                  || visibleStaircases.size() > 0)) {
         roomVisibleArea = new Area(getShape(points));
         if (roomsAtSameElevation.contains(room)) {
           // Remove other rooms surface that may overlap the current room
@@ -264,7 +303,7 @@ public class Room3D extends Object3DBranch {
             Room otherRoom = roomsAtSameElevation.get(i);
             roomVisibleArea.subtract(new Area(getShape(otherRoom.getPoints())));
           }
-        }        
+        }
         removeStaircasesFromArea(visibleStaircases, roomVisibleArea);
         roomPoints = new ArrayList<float[][]>();
         roomHoles = new ArrayList<float[][]>();
@@ -273,18 +312,18 @@ public class Room3D extends Object3DBranch {
         boolean clockwise = room.isClockwise();
         if (clockwise && roomPart == FLOOR_PART
             || !clockwise && roomPart == CEILING_PART) {
-          // Reverse points order 
+          // Reverse points order
           points = getReversedArray(points);
         }
-        roomPointsWithoutHoles = 
+        roomPointsWithoutHoles =
         roomPoints = Arrays.asList(new float [][][] {points});
         roomHoles = Collections.emptyList();
         roomVisibleArea = null;
       }
-      
-      List<Geometry> geometries = new ArrayList<Geometry> (3);      
+
+      List<Geometry> geometries = new ArrayList<Geometry> (3);
       final float subpartSize = this.home.getEnvironment().getSubpartSizeUnderLight();
-      
+
       if (!roomPointsWithoutHoles.isEmpty()) {
         List<float []> roomPointElevations = new ArrayList<float[]>();
         boolean roomAtSameElevation = true;
@@ -292,8 +331,8 @@ public class Room3D extends Object3DBranch {
           float [][] roomPartPoints = roomPointsWithoutHoles.get(i);
           float [] roomPartPointElevations = new float [roomPartPoints.length];
           for (int j = 0; j < roomPartPoints.length; j++) {
-            roomPartPointElevations [j] = roomPart == FLOOR_PART 
-                ? roomElevation 
+            roomPartPointElevations [j] = roomPart == FLOOR_PART
+                ? roomElevation
                 : getRoomHeightAt(roomPartPoints [j][0], roomPartPoints [j][1]);
             if (roomAtSameElevation && j > 0) {
               roomAtSameElevation = roomPartPointElevations [j] == roomPartPointElevations [j - 1];
@@ -306,7 +345,7 @@ public class Room3D extends Object3DBranch {
         if (roomAtSameElevation && subpartSize > 0) {
           for (int i = 0; i < roomPointsWithoutHoles.size(); i++) {
             float [][] roomPartPoints = roomPointsWithoutHoles.get(i);
-            // Subdivide area in smaller squares to ensure a smoother effect with point lights         
+            // Subdivide area in smaller squares to ensure a smoother effect with point lights
             float xMin = Float.MAX_VALUE;
             float xMax = Float.MIN_VALUE;
             float zMin = Float.MAX_VALUE;
@@ -317,18 +356,18 @@ public class Room3D extends Object3DBranch {
               zMin = Math.min(zMin, point [1]);
               zMax = Math.max(zMax, point [1]);
             }
-            
-            Area roomPartArea = new Area(getShape(roomPartPoints));        
+
+            Area roomPartArea = new Area(getShape(roomPartPoints));
             for (float xSquare = xMin; xSquare < xMax; xSquare += subpartSize) {
               for (float zSquare = zMin; zSquare < zMax; zSquare += subpartSize) {
                 Area roomPartSquare = new Area(new Rectangle2D.Float(xSquare, zSquare, subpartSize, subpartSize));
                 roomPartSquare.intersect(roomPartArea);
                 if (!roomPartSquare.isEmpty()) {
-                  List<float [][]> geometryPartPointsWithoutHoles = 
+                  List<float [][]> geometryPartPointsWithoutHoles =
                       getAreaPoints(roomPartSquare, 1, roomPart == CEILING_PART);
                   if (!geometryPartPointsWithoutHoles.isEmpty()) {
-                    geometries.add(computeRoomPartGeometry(geometryPartPointsWithoutHoles, 
-                        null, roomLevel, roomPointElevations.get(i) [0], floorBottomElevation, 
+                    geometries.add(computeRoomPartGeometry(geometryPartPointsWithoutHoles,
+                        null, roomLevel, roomPointElevations.get(i) [0], floorBottomElevation,
                         roomPart == FLOOR_PART, false, texture));
                   }
                 }
@@ -339,10 +378,10 @@ public class Room3D extends Object3DBranch {
           geometries.add(computeRoomPartGeometry(roomPointsWithoutHoles, roomPointElevations, roomLevel,
               roomElevation, floorBottomElevation, roomPart == FLOOR_PART, false, texture));
         }
-          
+
         // Compute border geometry
         if (roomLevel != null
-            && roomPart == FLOOR_PART 
+            && roomPart == FLOOR_PART
             && roomLevel.getElevation() != firstLevelElevation) {
           geometries.add(computeRoomBorderGeometry(roomPoints, roomHoles, roomLevel, roomElevation, texture));
         }
@@ -351,18 +390,18 @@ public class Room3D extends Object3DBranch {
       // Retrieve points of the room floor bottom
       if (floorBottomVisible) {
         List<float [][]> floorBottomPointsWithoutHoles;
-        if (roomVisibleArea != null 
-            || ceilingsAtSameFloorBottomElevation.size() > 0) {        
+        if (roomVisibleArea != null
+            || ceilingsAtSameFloorBottomElevation.size() > 0) {
           Area floorBottomVisibleArea = roomVisibleArea != null ? roomVisibleArea : new Area(getShape(points));
           // Remove other rooms surface that may overlap the floor bottom
           for (Room otherRoom : ceilingsAtSameFloorBottomElevation) {
            floorBottomVisibleArea.subtract(new Area(getShape(otherRoom.getPoints())));
-          }          
+          }
           floorBottomPointsWithoutHoles = getAreaPoints(floorBottomVisibleArea, 1, true);
         } else {
           floorBottomPointsWithoutHoles = Arrays.asList(new float [][][] {getReversedArray(points)});
         }
-        
+
         if (!floorBottomPointsWithoutHoles.isEmpty()) {
           // Compute floor bottom geometry
           if (subpartSize > 0) {
@@ -378,7 +417,7 @@ public class Room3D extends Object3DBranch {
                 zMin = Math.min(zMin, point [1]);
                 zMax = Math.max(zMax, point [1]);
               }
-              
+
               Area floorBottomPartArea = new Area(getShape(floorBottomPartPoints));
               for (float xSquare = xMin; xSquare < xMax; xSquare += subpartSize) {
                 for (float zSquare = zMin; zSquare < zMax; zSquare += subpartSize) {
@@ -387,8 +426,8 @@ public class Room3D extends Object3DBranch {
                   if (!floorBottomPartSquare.isEmpty()) {
                     List<float [][]> geometryPartPointsWithoutHoles = getAreaPoints(floorBottomPartSquare, 1, true);
                     if (!geometryPartPointsWithoutHoles.isEmpty()) {
-                      geometries.add(computeRoomPartGeometry(geometryPartPointsWithoutHoles, 
-                          null, roomLevel, roomElevation, floorBottomElevation, 
+                      geometries.add(computeRoomPartGeometry(geometryPartPointsWithoutHoles,
+                          null, roomLevel, roomElevation, floorBottomElevation,
                           true, true, texture));
                     }
                   }
@@ -411,18 +450,18 @@ public class Room3D extends Object3DBranch {
   /**
    * Returns the room part geometry matching the given points.
    */
-  private Geometry computeRoomPartGeometry(List<float [][]> geometryPoints, 
+  private Geometry computeRoomPartGeometry(List<float [][]> geometryPoints,
                                            List<float []> roomPointElevations,
                                            Level roomLevel,
                                            float roomPartElevation, float floorBottomElevation,
-                                           boolean floorPart, boolean floorBottomPart, 
+                                           boolean floorPart, boolean floorBottomPart,
                                            HomeTexture texture) {
     int [] stripCounts = new int [geometryPoints.size()];
     int vertexCount = 0;
     for (int i = 0; i < geometryPoints.size(); i++) {
       float [][] areaPoints = geometryPoints.get(i);
       stripCounts [i] = areaPoints.length;
-      vertexCount += stripCounts [i]; 
+      vertexCount += stripCounts [i];
     }
     Point3f [] coords = new Point3f [vertexCount];
     int i = 0;
@@ -432,8 +471,8 @@ public class Room3D extends Object3DBranch {
           ? roomPointElevations.get(j)
           : null;
       for (int k = 0; k < areaPoints.length; k++) {
-        float y = floorBottomPart 
-            ? floorBottomElevation 
+        float y = floorBottomPart
+            ? floorBottomElevation
             : (roomPartPointElevations != null
                   ? roomPartPointElevations [k]
                   : roomPartElevation);
@@ -443,15 +482,15 @@ public class Room3D extends Object3DBranch {
     GeometryInfo geometryInfo = new GeometryInfo(GeometryInfo.POLYGON_ARRAY);
     geometryInfo.setCoordinates(coords);
     geometryInfo.setStripCounts(stripCounts);
-    
+
     if (texture != null) {
       TexCoord2f [] textureCoords = new TexCoord2f [vertexCount];
       i = 0;
       // Compute room texture coordinates
       for (float [][] areaPoints : geometryPoints) {
         for (int k = 0; k < areaPoints.length; k++) {
-          textureCoords [i++] = new TexCoord2f(areaPoints [k][0], 
-              floorPart 
+          textureCoords [i++] = new TexCoord2f(areaPoints [k][0],
+              floorPart
                   ? -areaPoints [k][1]
                   : areaPoints [k][1]);
         }
@@ -459,7 +498,7 @@ public class Room3D extends Object3DBranch {
       geometryInfo.setTextureCoordinateParams(1, 2);
       geometryInfo.setTextureCoordinates(0, textureCoords);
     }
-    
+
     // Generate normals
     new NormalGenerator().generateNormals(geometryInfo);
     return geometryInfo.getIndexedGeometryArray();
@@ -468,9 +507,9 @@ public class Room3D extends Object3DBranch {
   /**
    * Returns the room border geometry matching the given points.
    */
-  private Geometry computeRoomBorderGeometry(List<float [][]> geometryRooms, 
+  private Geometry computeRoomBorderGeometry(List<float [][]> geometryRooms,
                                              List<float [][]> geometryHoles,
-                                             Level roomLevel, float roomElevation, 
+                                             Level roomLevel, float roomElevation,
                                              HomeTexture texture) {
     int vertexCount = 0;
     for (float [][] geometryPoints : geometryRooms) {
@@ -489,7 +528,7 @@ public class Room3D extends Object3DBranch {
       for (int j = 0; j < geometryPoints.length; j++) {
         coords [i++] = new Point3f(geometryPoints [j][0], roomElevation, geometryPoints [j][1]);
         coords [i++] = new Point3f(geometryPoints [j][0], floorBottomElevation, geometryPoints [j][1]);
-        int nextPoint = j < geometryPoints.length - 1  
+        int nextPoint = j < geometryPoints.length - 1
             ? j + 1
             : 0;
         coords [i++] = new Point3f(geometryPoints [nextPoint][0], floorBottomElevation, geometryPoints [nextPoint][1]);
@@ -500,7 +539,7 @@ public class Room3D extends Object3DBranch {
     for (float [][] geometryHole : geometryHoles) {
       for (int j = 0; j < geometryHole.length; j++) {
         coords [i++] = new Point3f(geometryHole [j][0], roomElevation, geometryHole [j][1]);
-        int nextPoint = j < geometryHole.length - 1  
+        int nextPoint = j < geometryHole.length - 1
             ? j + 1
             : 0;
         coords [i++] = new Point3f(geometryHole [nextPoint][0], roomElevation, geometryHole [nextPoint][1]);
@@ -511,7 +550,7 @@ public class Room3D extends Object3DBranch {
 
     GeometryInfo geometryInfo = new GeometryInfo(GeometryInfo.QUAD_ARRAY);
     geometryInfo.setCoordinates(coords);
-    
+
     if (texture != null) {
       TexCoord2f [] textureCoords = new TexCoord2f [vertexCount];
       i = 0;
@@ -520,10 +559,10 @@ public class Room3D extends Object3DBranch {
         for (int j = 0; j < geometryPoints.length; j++) {
           textureCoords [i++] = new TexCoord2f(0, roomLevel.getFloorThickness());
           textureCoords [i++] = new TexCoord2f(0, 0);
-          int nextPoint = j < geometryPoints.length - 1  
+          int nextPoint = j < geometryPoints.length - 1
               ? j + 1
               : 0;
-          float textureCoord = (float)(Point2D.distance(geometryPoints [j][0], geometryPoints [j][1], 
+          float textureCoord = (float)(Point2D.distance(geometryPoints [j][0], geometryPoints [j][1],
               geometryPoints [nextPoint][0], geometryPoints [nextPoint][1]));
           textureCoords [i++] = new TexCoord2f(textureCoord, 0);
           textureCoords [i++] = new TexCoord2f(textureCoord, roomLevel.getFloorThickness());
@@ -533,10 +572,10 @@ public class Room3D extends Object3DBranch {
       for (float [][] geometryHole : geometryHoles) {
         for (int j = 0; j < geometryHole.length; j++) {
           textureCoords [i++] = new TexCoord2f(0, 0);
-          int nextPoint = j < geometryHole.length - 1  
+          int nextPoint = j < geometryHole.length - 1
               ? j + 1
               : 0;
-          float textureCoord = (float)(Point2D.distance(geometryHole [j][0], geometryHole [j][1], 
+          float textureCoord = (float)(Point2D.distance(geometryHole [j][0], geometryHole [j][1],
               geometryHole [nextPoint][0], geometryHole [nextPoint][1]));
           textureCoords [i++] = new TexCoord2f(textureCoord, 0);
           textureCoords [i++] = new TexCoord2f(textureCoord, roomLevel.getFloorThickness());
@@ -546,7 +585,7 @@ public class Room3D extends Object3DBranch {
       geometryInfo.setTextureCoordinateParams(1, 2);
       geometryInfo.setTextureCoordinates(0, textureCoords);
     }
-    
+
     // Generate normals
     new NormalGenerator(Math.PI / 8).generateNormals(geometryInfo);
     return geometryInfo.getIndexedGeometryArray();
@@ -561,9 +600,9 @@ public class Room3D extends Object3DBranch {
   }
 
   /**
-   * Returns the visible staircases among the given <code>furniture</code>.  
+   * Returns the visible staircases among the given <code>furniture</code>.
    */
-  private List<HomePieceOfFurniture> getVisibleStaircases(List<HomePieceOfFurniture> furniture, 
+  private List<HomePieceOfFurniture> getVisibleStaircases(List<HomePieceOfFurniture> furniture,
                                                           int roomPart, Level roomLevel,
                                                           boolean firstLevel) {
     List<HomePieceOfFurniture> visibleStaircases = new ArrayList<HomePieceOfFurniture>(furniture.size());
@@ -575,7 +614,7 @@ public class Room3D extends Object3DBranch {
           visibleStaircases.addAll(getVisibleStaircases(((HomeFurnitureGroup)piece).getFurniture(), roomPart, roomLevel, firstLevel));
         } else if (piece.getStaircaseCutOutShape() != null
             && !"false".equalsIgnoreCase(piece.getStaircaseCutOutShape())
-            && ((roomPart == FLOOR_PART 
+            && ((roomPart == FLOOR_PART
                     && piece.getGroundElevation() < roomLevel.getElevation()
                     && piece.getGroundElevation() + piece.getHeight() >= roomLevel.getElevation() - (firstLevel ? 0 : roomLevel.getFloorThickness())
                 || roomPart == CEILING_PART
@@ -597,9 +636,9 @@ public class Room3D extends Object3DBranch {
     Collections.reverse(pointList);
     return pointList.toArray(points);
   }
-  
+
   /**
-   * Returns the room height at the given point. 
+   * Returns the room height at the given point.
    */
   private float getRoomHeightAt(float x, float y) {
     double smallestDistance = Float.POSITIVE_INFINITY;
@@ -608,7 +647,7 @@ public class Room3D extends Object3DBranch {
     float roomElevation = roomLevel != null
         ? roomLevel.getElevation()
         : 0;
-    float roomHeight = roomElevation + 
+    float roomHeight = roomElevation +
         (roomLevel == null ? this.home.getWallHeight() : roomLevel.getHeight());
     List<Level> levels = this.home.getLevels();
     if (roomLevel == null || isLastLevel(roomLevel, levels)) {
@@ -631,20 +670,20 @@ public class Room3D extends Object3DBranch {
           }
         }
       }
-      
+
       if (closestWall != null) {
         roomHeight = closestWall.getLevel() == null ? 0 : closestWall.getLevel().getElevation();
         Float wallHeightAtStart = closestWall.getHeight();
         if (closestIndex == 0 || closestIndex == closestWallPoints.length - 1) { // Wall start
-          roomHeight += wallHeightAtStart != null 
-              ? wallHeightAtStart 
+          roomHeight += wallHeightAtStart != null
+              ? wallHeightAtStart
               : this.home.getWallHeight();
         } else { // Wall end
           if (closestWall.isTrapezoidal()) {
             Float arcExtent = closestWall.getArcExtent();
             if (arcExtent == null
                 || arcExtent.floatValue() == 0
-                || closestIndex == closestWallPoints.length / 2 
+                || closestIndex == closestWallPoints.length / 2
                 || closestIndex == closestWallPoints.length / 2 - 1) {
               roomHeight += closestWall.getHeightAtEnd();
             } else {
@@ -658,11 +697,11 @@ public class Room3D extends Object3DBranch {
               float xStart = closestWall.getXStart();
               float yStart = closestWall.getYStart();
               double centerToStartPointDistance = Point2D.distance(xArcCircleCenter, yArcCircleCenter, xStart, yStart);
-              double scalarProduct = (xClosestPoint - xArcCircleCenter) * (xStart - xArcCircleCenter) 
+              double scalarProduct = (xClosestPoint - xArcCircleCenter) * (xStart - xArcCircleCenter)
                   + (yClosestPoint - yArcCircleCenter) * (yStart - yArcCircleCenter);
               scalarProduct /= (centerToClosestPointDistance * centerToStartPointDistance);
               double arcExtentToClosestWallPoint = Math.acos(scalarProduct) * Math.signum(arcExtent);
-              roomHeight += (float)(wallHeightAtStart 
+              roomHeight += (float)(wallHeightAtStart
                   + (closestWall.getHeightAtEnd() - wallHeightAtStart) * arcExtentToClosestWallPoint / arcExtent);
             }
           } else {
@@ -673,7 +712,7 @@ public class Room3D extends Object3DBranch {
     }
     return roomHeight;
   }
-  
+
   /**
    * Returns <code>true</code> if the given level is the last level in home.
    */
@@ -686,25 +725,37 @@ public class Room3D extends Object3DBranch {
    */
   private void updateRoomAppearance(boolean waitTextureLoadingEnd) {
     Room room = (Room)getUserData();
+    Group roomFloorGroup = (Group)getChild(FLOOR_PART);
     boolean ignoreFloorTransparency = room.getLevel() == null || room.getLevel().getElevation() <= 0;
-    updateRoomPartAppearance(((Shape3D)getChild(FLOOR_PART)).getAppearance(), 
-        room.getFloorTexture(), waitTextureLoadingEnd, room.getFloorColor(), room.getFloorShininess(), room.isFloorVisible(), ignoreFloorTransparency);
-    // Ignore ceiling transparency for rooms without level for backward compatibility 
-    boolean ignoreCeillingTransparency = room.getLevel() == null; 
-    updateRoomPartAppearance(((Shape3D)getChild(CEILING_PART)).getAppearance(), 
-        room.getCeilingTexture(), waitTextureLoadingEnd, room.getCeilingColor(), room.getCeilingShininess(), room.isCeilingVisible(), ignoreCeillingTransparency);
+    updateFilledRoomPartAppearance(((Shape3D)roomFloorGroup.getChild(0)).getAppearance(),
+        room.getFloorTexture(), waitTextureLoadingEnd, room.getFloorColor(), room.getFloorShininess(),
+        room.isFloorVisible(), ignoreFloorTransparency, roomFloorGroup.numChildren() == 1);
+    if (roomFloorGroup.numChildren() > 1) {
+      updateOutlineRoomPartAppearance(((Shape3D)roomFloorGroup.getChild(1)).getAppearance(), room.isFloorVisible());
+    }
+
+    Group roomCeilingGroup = (Group)getChild(CEILING_PART);
+    // Ignore ceiling transparency for rooms without level for backward compatibility
+    boolean ignoreCeillingTransparency = room.getLevel() == null;
+    updateFilledRoomPartAppearance(((Shape3D)roomCeilingGroup.getChild(0)).getAppearance(),
+        room.getCeilingTexture(), waitTextureLoadingEnd, room.getCeilingColor(), room.getCeilingShininess(),
+        room.isCeilingVisible(), ignoreCeillingTransparency, roomCeilingGroup.numChildren() == 1);
+    if (roomCeilingGroup.numChildren() > 1) {
+      updateOutlineRoomPartAppearance(((Shape3D)roomCeilingGroup.getChild(1)).getAppearance(), room.isCeilingVisible());
+    }
   }
-  
+
   /**
-   * Sets room part appearance with its color, texture and visibility.
+   * Sets filled room part appearance with its color, texture and visibility.
    */
-  private void updateRoomPartAppearance(final Appearance roomPartAppearance, 
-                                        final HomeTexture roomPartTexture,
-                                        boolean waitTextureLoadingEnd,
-                                        Integer roomPartColor,
-                                        float shininess,
-                                        boolean visible,
-                                        boolean ignoreTransparency) {
+  private void updateFilledRoomPartAppearance(final Appearance roomPartAppearance,
+                                             final HomeTexture roomPartTexture,
+                                             boolean waitTextureLoadingEnd,
+                                             Integer roomPartColor,
+                                             float shininess,
+                                             boolean visible,
+                                             boolean ignoreTransparency,
+                                             boolean ignoreDrawingMode) {
     if (roomPartTexture == null) {
       roomPartAppearance.setMaterial(getMaterial(roomPartColor, roomPartColor, shininess));
       roomPartAppearance.setTexture(null);
@@ -723,18 +774,36 @@ public class Room3D extends Object3DBranch {
               }
             });
     }
-    if (!ignoreTransparency) { 
+    if (!ignoreTransparency) {
       // Update room part transparency
       float upperRoomsAlpha = this.home.getEnvironment().getWallsAlpha();
       TransparencyAttributes transparencyAttributes = roomPartAppearance.getTransparencyAttributes();
       transparencyAttributes.setTransparency(upperRoomsAlpha);
-      // If alpha is equal to zero, turn off transparency to get better results 
-      transparencyAttributes.setTransparencyMode(upperRoomsAlpha == 0 
-          ? TransparencyAttributes.NONE 
+      // If alpha is equal to zero, turn off transparency to get better results
+      transparencyAttributes.setTransparencyMode(upperRoomsAlpha == 0
+          ? TransparencyAttributes.NONE
           : TransparencyAttributes.NICEST);
     }
     // Update room part visibility
     RenderingAttributes renderingAttributes = roomPartAppearance.getRenderingAttributes();
-    renderingAttributes.setVisible(visible);
+    HomeEnvironment.DrawingMode drawingMode = this.home.getEnvironment().getDrawingMode();
+    renderingAttributes.setVisible(visible
+        && (ignoreDrawingMode
+            || drawingMode == null
+            || drawingMode == HomeEnvironment.DrawingMode.FILL
+            || drawingMode == HomeEnvironment.DrawingMode.FILL_AND_OUTLINE));
+  }
+
+  /**
+   * Sets outline wall side visibility.
+   */
+  private void updateOutlineRoomPartAppearance(final Appearance roomPartAppearance,
+                                               boolean visible) {
+    // Update room part visibility
+    RenderingAttributes renderingAttributes = roomPartAppearance.getRenderingAttributes();
+    HomeEnvironment.DrawingMode drawingMode = this.home.getEnvironment().getDrawingMode();
+    renderingAttributes.setVisible(visible
+        && (drawingMode == HomeEnvironment.DrawingMode.OUTLINE
+            || drawingMode == HomeEnvironment.DrawingMode.FILL_AND_OUTLINE));
   }
 }
\ No newline at end of file
