@@ -1,19 +1,19 @@
 /*
  * HomeFileRecorderTest.java 28 aout 2006
- * 
+ *
  * Copyright (c) 2006 Emmanuel PUYBARET / eTeks <info@eteks.com>. All Rights
  * Reserved.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
  * Foundation; either version 2 of the License, or (at your option) any later
  * version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
  * details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along with
  * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
  * Place, Suite 330, Boston, MA 02111-1307 USA
@@ -30,6 +30,7 @@ import java.util.Arrays;
 
 import com.eteks.sweethome3d.io.DefaultFurnitureCatalog;
 import com.eteks.sweethome3d.io.DefaultUserPreferences;
+import com.eteks.sweethome3d.io.FileUserPreferences;
 import com.eteks.sweethome3d.io.HomeFileRecorder;
 import com.eteks.sweethome3d.model.Content;
 import com.eteks.sweethome3d.model.DamagedHomeRecorderException;
@@ -63,30 +64,30 @@ public class HomeFileRecorderTest extends TestCase {
     piece.setProperty("id", "piece1");
     piece.setProperty("name", "value");
     home1.addPieceOfFurniture(piece);
-    
+
     // Test if home is correctly saved
     checkSavedHome(home1, new HomeFileRecorder());
     // Test if home with XML entry is correctly saved
     checkSavedHome(home1, new HomeFileRecorder(9, false, null, false, true));
   }
-  
+
   private void checkSavedHome(Home home, HomeRecorder recorder) throws RecorderException {
     // 1. Record home in a file named test.sh3d in current directory
     String testFile = new File("test.sh3d").getAbsolutePath();
-    recorder.writeHome(home, testFile); 
+    recorder.writeHome(home, testFile);
     // Check test.sh3d file exists
     assertTrue("File test.sh3d doesn't exist", recorder.exists(testFile));
-    
+
     // 2. Read test.sh3d file in a new home
     Home readHome = recorder.readHome(testFile);
     // Compare home content
     assertNotSame("Home not loaded", home, readHome);
-    assertEquals("Home wall height", 
+    assertEquals("Home wall height",
         home.getWallHeight(), readHome.getWallHeight());
-    assertEquals("Home walls wrong count", 
+    assertEquals("Home walls wrong count",
         home.getWalls().size(), readHome.getWalls().size());
     assertEquals(home.getWalls().iterator().next(), readHome.getWalls().iterator().next());
-    assertEquals("Home furniture wrong count", 
+    assertEquals("Home furniture wrong count",
         home.getFurniture().size(), readHome.getFurniture().size());
     assertEquals(home.getFurniture().iterator().next(), readHome.getFurniture().get(0));
 
@@ -95,10 +96,10 @@ public class HomeFileRecorderTest extends TestCase {
       fail("Couldn't delete file " + testFile);
     }
   }
-  
+
   public void testXMLEntryConsistency() throws URISyntaxException, RecorderException, IOException {
     checkXMLEntryConsistency(new File(HomeControllerTest.class.getResource("resources/home1.sh3d").toURI()));
-    
+
     // Create a home with properties and text style set on group items
     Home home = new Home();
     Level level0 = new Level("Level0", 0, 0.1f, 250f);
@@ -123,7 +124,7 @@ public class HomeFileRecorderTest extends TestCase {
     checkXMLEntryConsistency(savedFileWithHomeEntry);
     savedFileWithHomeEntry.delete();
   }
-  
+
   public void checkXMLEntryConsistency(File homeFile) throws RecorderException, IOException {
     HomeRecorder homeEntryRecorder = new HomeFileRecorder(0, false, null, false, false);
     Home home = homeEntryRecorder.readHome(homeFile.getAbsolutePath());
@@ -138,21 +139,21 @@ public class HomeFileRecorderTest extends TestCase {
     File savedFileWithXmlEntry2 = File.createTempFile("homeXML", ".sh3d");
     homeXmlEntryRecorder.writeHome(home, savedFileWithXmlEntry2.getAbsolutePath());
     // Compare the XML entries of the two files
-    assertContentEquals("Home.xml entries different", 
-        new URLContent(new URL("jar:" + savedFileWithXmlEntry.toURI().toURL() + "!/Home.xml")), 
+    assertContentEquals("Home.xml entries different",
+        new URLContent(new URL("jar:" + savedFileWithXmlEntry.toURI().toURL() + "!/Home.xml")),
         new URLContent(new URL("jar:" + savedFileWithXmlEntry2.toURI().toURL() + "!/Home.xml")));
     savedFileWithXmlEntry.delete();
     savedFileWithXmlEntry2.delete();
   }
-  
+
   /**
    * Test repaired home file management.
    */
   public void testRepairedFile() throws URISyntaxException, RecorderException, IOException {
-    // Test repair on corrupted file 
+    // Test repair on corrupted file
     checkDamagedFileIsRepaired(new File(
         HomeControllerTest.class.getResource("resources/damagedHomeWithContentDigests.sh3d").toURI()).getAbsolutePath(), 5);
-    // Test repair on valid zip file but with missing entries 
+    // Test repair on valid zip file but with missing entries
     checkDamagedFileIsRepaired(new File(
         HomeControllerTest.class.getResource("resources/damagedHomeInValidZipWithContentDigestsAndNoContent.sh3d").toURI()).getAbsolutePath(), 9);
   }
@@ -181,15 +182,26 @@ public class HomeFileRecorderTest extends TestCase {
   }
 
   /**
-   * Asserts <code>wall1</code> and <code>wall2</code> are different walls 
-   * containing the same data. 
+   * Test direct reading of a XML file.
+   */
+  public void testReadXMLFile() throws RecorderException, URISyntaxException {
+    HomeRecorder recorder = new HomeFileRecorder(0, false, new FileUserPreferences(), false, true, false);
+    Home home = recorder.readHome(new File(
+        HomeControllerTest.class.getResource("resources/homeTest.xml").toURI()).getAbsolutePath());
+    assertEquals("Incorrect furniture count", 2, home.getFurniture().size());
+    assertEquals("Incorrect walls count", 4, home.getWalls().size());
+  }
+
+  /**
+   * Asserts <code>wall1</code> and <code>wall2</code> are different walls
+   * containing the same data.
    */
   private void assertEquals(Wall wall1, Wall wall2) {
     assertNotSame("Wall not loaded", wall1, wall2);
-    assertEquals("Different X start", wall1.getXStart(), wall2.getXStart());     
-    assertEquals("Different Y start", wall1.getYStart(), wall2.getYStart());     
-    assertEquals("Different X end", wall1.getXEnd(), wall2.getXEnd());     
-    assertEquals("Different Y end", wall1.getYEnd(), wall2.getYEnd());     
+    assertEquals("Different X start", wall1.getXStart(), wall2.getXStart());
+    assertEquals("Different Y start", wall1.getYStart(), wall2.getYStart());
+    assertEquals("Different X end", wall1.getXEnd(), wall2.getXEnd());
+    assertEquals("Different Y end", wall1.getYEnd(), wall2.getYEnd());
     assertEquals("Different thickness", wall1.getThickness(), wall2.getThickness());
     if (wall1.getWallAtStart() == null) {
       assertEquals("Different wall at start", wall2.getWallAtStart(), null);
@@ -203,28 +215,28 @@ public class HomeFileRecorderTest extends TestCase {
       assertFalse("Different wall at end", wall2.getWallAtEnd() == null);
       assertNotSame("Wall at end not loaded", wall1.getWallAtStart(), wall2.getWallAtEnd());
     }
-    assertEquals("Different property id", wall1.getProperty("id"), wall2.getProperty("id"));     
+    assertEquals("Different property id", wall1.getProperty("id"), wall2.getProperty("id"));
   }
 
   /**
-   * Asserts <code>piece1</code> and <code>piece2</code> are different pieces 
+   * Asserts <code>piece1</code> and <code>piece2</code> are different pieces
    * containing the same data.
    */
   private void assertEquals(HomePieceOfFurniture piece1, HomePieceOfFurniture piece2) {
     assertNotSame("Piece not loaded", piece1, piece2);
-    assertEquals("Different X", piece1.getX(), piece2.getX());     
-    assertEquals("Different Y", piece1.getY(), piece2.getY());     
-    assertEquals("Different color", piece1.getColor(), piece2.getColor());     
-    assertEquals("Different width", piece1.getWidth(), piece2.getWidth());     
-    assertEquals("Different height", piece1.getHeight(), piece2.getHeight());     
-    assertEquals("Different depth", piece1.getDepth(), piece2.getDepth());     
-    assertEquals("Different name", piece1.getName(), piece2.getName());     
+    assertEquals("Different X", piece1.getX(), piece2.getX());
+    assertEquals("Different Y", piece1.getY(), piece2.getY());
+    assertEquals("Different color", piece1.getColor(), piece2.getColor());
+    assertEquals("Different width", piece1.getWidth(), piece2.getWidth());
+    assertEquals("Different height", piece1.getHeight(), piece2.getHeight());
+    assertEquals("Different depth", piece1.getDepth(), piece2.getDepth());
+    assertEquals("Different name", piece1.getName(), piece2.getName());
     assertNotSame("Piece icon not loaded", piece1.getIcon(), piece2.getIcon());
-    assertContentEquals("Different icon content", piece1.getIcon(), piece2.getIcon());     
+    assertContentEquals("Different icon content", piece1.getIcon(), piece2.getIcon());
     assertNotSame("Piece model not loaded", piece1.getModel(), piece2.getModel());
-    assertContentEquals("Different model content", piece1.getModel(), piece2.getModel());     
-    assertEquals("Different property id", piece1.getProperty("id"), piece2.getProperty("id"));     
-    assertEquals("Different property name", piece1.getProperty("name"), piece2.getProperty("name"));     
+    assertContentEquals("Different model content", piece1.getModel(), piece2.getModel());
+    assertEquals("Different property id", piece1.getProperty("id"), piece2.getProperty("id"));
+    assertEquals("Different property name", piece1.getProperty("name"), piece2.getProperty("name"));
   }
 
   /**
@@ -237,7 +249,7 @@ public class HomeFileRecorderTest extends TestCase {
       stream1 = new BufferedInputStream(content1.openStream());
       stream2 = new BufferedInputStream(content2.openStream());
       for (int b; (b = stream1.read()) != -1; ) {
-        assertEquals(message, b, stream2.read());   
+        assertEquals(message, b, stream2.read());
       }
       assertEquals(message, -1, stream2.read());
     } catch (IOException ex) {
